@@ -5,6 +5,7 @@ import socket
 from dns import resolver
 from tld import get_tld, is_tld
 from json import dumps
+from typing import Tuple
 
 from requests.exceptions import ConnectionError
 from socket import gaierror
@@ -136,7 +137,7 @@ class DomainValidator:
                     if "v=DKIM1" in str(response):
                         self._dkim_results = True
                         return
-            except (resolver.NXDOMAIN, resolver.NoAnswer):
+            except (resolver.NXDOMAIN, resolver.NoAnswer, resolver.NoNameservers, resolver.LifetimeTimeout):
                 self._query_common_dkim_selectors()
                 return
         self._query_common_dkim_selectors()
@@ -156,7 +157,7 @@ class DomainValidator:
                 for response in results:
                     if "v=DKIM1" in str(response):
                         self._dkim_results = True
-            except (resolver.NXDOMAIN, resolver.NoAnswer, resolver.NoNameservers):
+            except (resolver.NXDOMAIN, resolver.NoAnswer, resolver.NoNameservers, resolver.LifetimeTimeout):
                 continue
 
     def _spf_validator(self):
@@ -169,7 +170,7 @@ class DomainValidator:
                 self._domain_name, 'TXT').response)
             if "v=spf1" in resolver_response:
                 self._spf_results = True
-        except (resolver.NXDOMAIN, resolver.NoAnswer, resolver.LifetimeTimeout):
+        except (resolver.NXDOMAIN, resolver.NoAnswer, resolver.NoNameservers, resolver.LifetimeTimeout):
             pass
 
         return
@@ -184,7 +185,7 @@ class DomainValidator:
         self._spf_validator()
 
 
-def validate_domain(domain_name: str, dkim_selector: str = None, raw_data=False) -> (bool, dict):
+def validate_domain(domain_name: str, dkim_selector: str = None, raw_data=False) -> Tuple[bool, dict]:
     """
     This function is used to allow the users to get the results without handling with the object itself.
     :param domain_name: The name of the domain - mandatory.
@@ -200,4 +201,4 @@ def validate_domain(domain_name: str, dkim_selector: str = None, raw_data=False)
     if not raw_data:
         return True if dv else False
     else:
-        return dv.__dict__()
+        return dv.__dict__()
\ No newline at end of file
